# -*- coding: utf-8 -*-

from django.contrib import admin
import rforum.models as mymodels
import forms as myforms
import socket

class AdminForum(admin.ModelAdmin):

    list_display = ('title', 'slug', 'order', 'status', 'visible',)
    # http://www.userlinux.net/django-los-campos-tipo-slug.html
    prepopulated_fields = { 'slug': ['title'] }

    """
    Para agregar TinyMCE en los newforms-admin:
    - http://code.djangoproject.com/wiki/AddWYSIWYGEditor#Withnewforms-admin
    - http://code.djangoproject.com/wiki/AddWYSIWYGEditor
    """

    class Media:
        js = ('js/tiny_mce/tiny_mce.js',
              'js/textareas.js',
              )


class AdminTopic(admin.ModelAdmin):

    list_display = ('title', 'forum', 'status', 'sticky', 'closed',)
    exclude = ('user',)

    def save_model(self, request, obj, form, change):
        obj.user = request.user
        obj.save()

    # http://www.userlinux.net/django-los-campos-tipo-slug.html
    prepopulated_fields = { 'slug': ['title'] }



class AdminPost(admin.ModelAdmin):

    list_display = ('body', 'topic', 'user', 'date_created', 'status',)
    #exclude = ('user',)

    def save_model(self, request, obj, form, change):
        obj.user = request.user
        obj.save()

    """
    Para agregar TinyMCE en los newforms-admin:
    - http://code.djangoproject.com/wiki/AddWYSIWYGEditor#Withnewforms-admin
    - http://code.djangoproject.com/wiki/AddWYSIWYGEditor
    """

    class Media:
        js = ('js/tiny_mce/tiny_mce.js',
              'js/textareas.js',
              )


class AdminLog(admin.ModelAdmin):

    list_display = ('user', 'action', 'date', 'user_ip',)


admin.site.register(mymodels.Forum, AdminForum)
admin.site.register(mymodels.Topic, AdminTopic)
admin.site.register(mymodels.Post, AdminPost)
admin.site.register(mymodels.Rank)
admin.site.register(mymodels.Log, AdminLog)



# -*- coding: utf-8 -*-

from django.conf.urls import patterns, include, url
from django.conf.urls.static import static
from django.conf import settings
from django.http import HttpResponseRedirect
import os
from rforum.views import UserProfile
from django.views.generic.simple import direct_to_template


# Uncomment the next two lines to enable the admin:
from django.contrib import admin
admin.autodiscover()

urlpatterns = patterns('',

    # Admin
    url(r'^tinymce/', include('tinymce.urls')),
    url(r'^admin/filebrowser/', include('filebrowser.urls')),
    url(r'^admin/', include(admin.site.urls)),

    # App_Foro
    url(r'^rforum/', include('rforum.urls')),
    url(r'^accounts/profile/$', UserProfile.as_view(), {}, "account_profile"), # App_Foro UserProfile

    # Accounts (Django-AllAuth)
    url(r'^accounts/', include('allauth.urls')),

)

# Media files (only for devel)
if settings.DEBUG:
    urlpatterns += patterns('',
        url(r'^media/(?P<path>.*)$', 'django.views.static.serve', {
            'document_root': settings.MEDIA_ROOT,
        }),
    )



# -*- coding: utf-8 -*-

from django import template
from django.utils.translation import ugettext as _
from rforum import utils

register = template.Library()

class EsModerador(template.Node):
    def __init__(self, usuario, topicslug):
        # Pasamos las variables a render
        self.usuario = template.Variable( usuario )
        self.topicslug = template.Variable( topicslug )

    def render(self, context):
        # Comprobamos lo que valen en su contexto
        usuario = self.usuario.resolve( context )
        topicslug = self.topicslug.resolve( context )

        # Seguimos con la lógica del filtro
        if utils.es_moderador(usuario, topicslug):
            return True
        else:
            return False


@register.tag
def es_moderador(parser, token):
    """
    Custom Tag que comprueba si es moderador o no, llama a la class EsModerador y
    devuelve True o False
    """
    try:
        tag_name, usuario, topicslug = token.split_contents()
    except ValueError:
        raise template.TemplateSyntaxError("%r tag requires exactly two arguments" % token.contents.split()[0])
    return EsModerador(usuario, topicslug)



# -*- coding: utf-8 -*-

from django.db import models
from django.contrib.auth.models import User
from django.db.models.signals import post_save
import models as mymodels

#def create_profile(sender, **kw):
#    user = kw["instance"]
#    if kw["created"]:
#        up = mymodels.UserProfile(user=user, twitter="@"+user.username)
#        up.save()

#post_save.connect(create_profile, sender=User)



# -*- coding: utf-8 -*-
import models as mymodels
from django.contrib.auth.models import User
from django.conf import settings as conf
from django.utils.translation import ugettext_lazy as _
from django.core.urlresolvers import reverse_lazy
from django.template.loader import render_to_string
from django.utils.html import strip_tags
from django.contrib.sites.models import Site


def es_suyo(usuario, id):

    """
    Devuelve True si el usuario es propietario del topic que le pasamos como
    parámetro o False si no lo es.
    """

    #User.objects.get(username=usuario)
    if usuario.is_superuser:
        return True

    mytopic = mymodels.Post.objects.get(id=id)

    #print "*"*80
    #print id
    #print usuario
    #print mytopic.user
    #print "*"*80
    #import pdb; pdb.set_trace()

    if(mytopic.user == usuario):
        return True
    else:
        return False


def es_moderador(usuario, topicslug):

    """
    Devuelve True si el usuario es moderador del foro al que corresponde el
    topic que le pasamos como parámetro o False si no lo es.
    """

    #print "--------------"
    #print usuario
    #print topicslug
    #import pdb; pdb.set_trace()

    #User.objects.get(username=usuario)
    if usuario.is_superuser:
        return True

    mytopic = mymodels.Topic.objects.get(slug=topicslug)
    moderators = mytopic.forum.moderators
    #print moderators.all()
    try:
        moderators.get(username=usuario)
        return True
    except User.DoesNotExist:
        return False


def grupo_moderadores(usuario):

    """
    Devuelve True si el usuario pertenece al grupo de moderadores
    o False si no lo es.
    """

    #import pdb; pdb.set_trace()
    #User.objects.get(username=usuario)
    #import pdb; pdb.set_trace()
    qs = User.objects.filter(groups__name=conf.MODERATORS_GROUP_NAME, username=usuario.username)

    if qs:
        #print "si"
        return True
    else:
        #print "no"
        return False


def mysendmail(email, mytype, arguments):

    current_site = Site.objects.get_current()

    # favour django-mailer but fall back to django.core.mail
    if "mailer" in conf.INSTALLED_APPS:
        from mailer import send_mail
        from mailer import send_html_mail
    else:
        from django.core.mail import send_mail
        from django.core.mail import send_mail as send_html_mail

    if mytype == 'newpost':
        subject =  _('[%s] New post in "%s"') % (conf.SITE_TITLE, arguments[0])
        from_email = conf.DEFAULT_FROM_EMAIL
        to = email
        html_content = render_to_string('rforum/email_subscribers_newpost.html',
                                        {'title': arguments[0],
                                        'slug': arguments[1],
                                        'topicslug': arguments[2],
                                        'domain': current_site.domain })
        text_content = strip_tags(html_content)

    if mytype == 'inappropiate':
        subject =  _('[%s] Post marked as inappropiate') % (conf.SITE_TITLE)
        from_email = conf.DEFAULT_FROM_EMAIL
        to = email
        html_content = render_to_string('rforum/email_inappropiate.html',
                                        {'slug': arguments[0],
                                        'domain': current_site.domain })
        text_content = strip_tags(html_content)

    send_html_mail(subject, text_content, html_content, from_email, [to])


